@@ -18,7 +18,6 @@
 # under the License.
 
 import abc
-import fnmatch
 import hashlib
 import os
 
@@ -36,6 +35,7 @@ from ceilometer.i18n import _, _LW
 from ceilometer import publisher
 from ceilometer.publisher import utils as publisher_utils
 from ceilometer import sample as sample_util
+from ceilometer import utils
 
 
 OPTS = [
@@ -272,11 +272,11 @@ class Source(object):
     def is_supported(dataset, data_name):
         # Support wildcard like storage.* and !disk.*
         # Start with negation, we consider that the order is deny, allow
-        if any(fnmatch.fnmatch(data_name, datapoint[1:])
+        if any(utils.match(data_name, datapoint[1:])
                for datapoint in dataset if datapoint[0] == '!'):
             return False
 
-        if any(fnmatch.fnmatch(data_name, datapoint)
+        if any(utils.match(data_name, datapoint)
                for datapoint in dataset if datapoint[0] != '!'):
             return True
 
