@@ -21,7 +21,6 @@ import mock
 from oslo_config import fixture as fixture_config
 from oslo_context import context
 import oslo_messaging
-import oslo_messaging.conffixture
 import oslo_service.service
 from oslo_utils import fileutils
 from oslo_utils import timeutils
@@ -154,10 +153,8 @@ class TestNotification(tests_base.BaseTestCase):
                          self.srv.listeners[0].dispatcher.endpoints[0])
 
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
-    @mock.patch.object(oslo_messaging.MessageHandlingServer, 'start',
-                       mock.MagicMock())
-    @mock.patch('ceilometer.event.endpoint.EventsNotificationEndpoint')
-    def test_unique_consumers(self, fake_event_endpoint_class):
+    @mock.patch('oslo_messaging.get_notification_listener')
+    def test_unique_consumers(self, mock_listener):
 
         def fake_get_notifications_manager_dup_targets(pm):
             plugin = instance.Instance(pm)
@@ -169,7 +166,10 @@ class TestNotification(tests_base.BaseTestCase):
                                '_get_notifications_manager') as get_nm:
             get_nm.side_effect = fake_get_notifications_manager_dup_targets
             self.srv.start()
-            self.assertEqual(1, len(self.srv.listeners[0].dispatcher.targets))
+            self.assertEqual(1, len(mock_listener.call_args_list))
+            args, kwargs = mock_listener.call_args
+            self.assertEqual(1, len(args[1]))
+            self.assertIsInstance(args[1][0], oslo_messaging.Target)
 
 
 class BaseRealNotification(tests_base.BaseTestCase):
@@ -465,21 +465,28 @@ class TestRealNotificationHA(BaseRealNotification):
             self.assertNotIn(listeners, set(self.srv.pipeline_listeners))
         self.srv.stop()
 
-    def test_retain_common_listeners_on_refresh(self):
+    @mock.patch('oslo_messaging.get_notification_listener')
+    def test_retain_common_targets_on_refresh(self, mock_listener):
+        def generate_random_object(*args, **kwargs):
+                        return mock.MagicMock()
+
+        mock_listener.side_effect = generate_random_object
+
         with mock.patch('ceilometer.coordination.PartitionCoordinator'
                         '.extract_my_subset', return_value=[1, 2]):
             self.srv.start()
-        self.assertEqual(4, len(self.srv.pipeline_listeners))
-        listeners = [listener for listener in self.srv.pipeline_listeners]
+        listened_before = [target.topic for target in
+                           mock_listener.call_args[0][1]]
+        self.assertEqual(1, len(listened_before))
         with mock.patch('ceilometer.coordination.PartitionCoordinator'
                         '.extract_my_subset', return_value=[1, 3]):
             self.srv._refresh_agent(None)
-        self.assertEqual(4, len(self.srv.pipeline_listeners))
-        for listener in listeners:
-            if listener.dispatcher.targets[0].topic.endswith('1'):
-                self.assertIn(listener, set(self.srv.pipeline_listeners))
-            else:
-                self.assertNotIn(listener, set(self.srv.pipeline_listeners))
+        listened_after = [target.topic for target in
+                          mock_listener.call_args[0][1]]
+        self.assertEqual(1, len(listened_after))
+        common = set(listened_before) & set(listened_after)
+        for topic in common:
+            self.assertTrue(topic.endswith('1'))
         self.srv.stop()
 
     @mock.patch('oslo_messaging.Notifier.sample')
