@@ -108,7 +108,8 @@ class DispatcherTest(base.BaseTestCase):
         self.assertIn('instance', names)
         self.assertIn('volume', names)
 
-    def test_broken_config_load(self):
+    @mock.patch('ceilometer.dispatcher.gnocchi.LOG')
+    def test_broken_config_load(self, mylog):
         contents = [("---\n"
                      "resources:\n"
                      "  - resource_type: foobar\n"),
@@ -135,8 +136,9 @@ class DispatcherTest(base.BaseTestCase):
             self.conf.config(filter_service_activity=False,
                              resources_definition_file=temp,
                              group='dispatcher_gnocchi')
-            self.assertRaises(gnocchi.ResourcesDefinitionException,
-                              gnocchi.GnocchiDispatcher, self.conf.conf)
+            d = gnocchi.GnocchiDispatcher(self.conf.conf)
+            self.assertTrue(mylog.error.called)
+            self.assertEqual(0, len(d.resources_definition))
 
     @mock.patch('ceilometer.dispatcher.gnocchi.GnocchiDispatcher'
                 '._process_resource')
@@ -235,7 +237,7 @@ class DispatcherWorkflowTest(base.BaseTestCase,
             metric_names=[
                 'instance', 'disk.root.size', 'disk.ephemeral.size',
                 'memory', 'vcpus', 'memory.usage', 'memory.resident',
-                'cpu', 'cpu_util', 'vcpus', 'disk.read.requests',
+                'cpu', 'cpu.delta', 'cpu_util', 'vcpus', 'disk.read.requests',
                 'disk.read.requests.rate', 'disk.write.requests',
                 'disk.write.requests.rate', 'disk.read.bytes',
                 'disk.read.bytes.rate', 'disk.write.bytes',
