@@ -33,19 +33,19 @@ class FakeObjectName(object):
         return str(self.name)
 
 
-def faux_getCmd_new(authData, transportTarget, *oids, **kwargs):
-    varBinds = [(FakeObjectName(oid),
-                 int(oid.split('.')[-1])) for oid in oids]
-    return (None, None, 0, varBinds)
+class FakeCommandGenerator(object):
+    def getCmd(self, authData, transportTarget, *oids, **kwargs):
+        varBinds = [(FakeObjectName(oid),
+                    int(oid.split('.')[-1])) for oid in oids]
+        return (None, None, 0, varBinds)
 
-
-def faux_bulkCmd_new(authData, transportTarget, nonRepeaters, maxRepetitions,
-                     *oids, **kwargs):
-    varBindTable = [
-        [(FakeObjectName(oid + ".%d" % i), i) for i in range(1, 3)]
-        for oid in oids
-    ]
-    return (None, None, 0, varBindTable)
+    def bulkCmd(authData, transportTarget, nonRepeaters, maxRepetitions,
+                *oids, **kwargs):
+        varBindTable = [
+            [(FakeObjectName("%s.%d" % (oid, i)), i) for i in range(1, 3)]
+            for oid in oids
+        ]
+        return (None, None, 0, varBindTable)
 
 
 class TestSNMPInspector(test_base.BaseTestCase):
@@ -73,9 +73,8 @@ class TestSNMPInspector(test_base.BaseTestCase):
         self.inspector = snmp.SNMPInspector()
         self.host = netutils.urlsplit("snmp://localhost")
         self.useFixture(mockpatch.PatchObject(
-            self.inspector._cmdGen, 'getCmd', new=faux_getCmd_new))
-        self.useFixture(mockpatch.PatchObject(
-            self.inspector._cmdGen, 'bulkCmd', new=faux_bulkCmd_new))
+            snmp.cmdgen, 'CommandGenerator',
+            return_value=FakeCommandGenerator()))
 
     def test_snmp_error(self):
         def get_list(func, *args, **kwargs):
@@ -133,8 +132,6 @@ class TestSNMPInspector(test_base.BaseTestCase):
         self.assertEqual(ret[0][0], ret[0][1]['meta'])
 
     def test_post_op_net(self):
-        self.useFixture(mockpatch.PatchObject(
-            self.inspector._cmdGen, 'bulkCmd', new=faux_bulkCmd_new))
         cache = {}
         metadata = dict(name='lo',
                         speed=0,
